VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
  Persistable = 0  'NotPersistable
  DataBindingBehavior = 0  'vbNone
  DataSourceBehavior  = 0  'vbNone
  MTSTransactionMode  = 0  'NotAnMTSObject
END
Attribute VB_Name = "Sample"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = True
Option Explicit



'---------------------------------------------------------------------------------------------------------------------------------------
'
'  Sample
'
'  eMedia plug-in
'
'---------------------------------------------------------------------------------------------------------------------------------------
'
' Purpose ...... This COM component will display a message for every operation done by the user.
' Author ....... Mediasoft Technologies
' Date ......... April 4, 2001 - modified december 12, 2002 - modified november 21, 2005
'
'---------------------------------------------------------------------------------------------------------------------------------------
'
' Handling errors:
'   eMedia handles errors from the Plug-In, and doesn't crash if the plug-in raise an error.
'   But eMedia doesn't display any message if the plug-in fires an error. You must handle
'   yourself your own errors.
'
' Functions:
'
'   Active
'     Set this property to True to receive the calls to the functions EPI_Job...
'
'   EPI_Initialize(String)
'     This method is called when eMedia needs the Plug-In to initialize itself
'     (when eMedia starts or when the user selects this plug-in). The constuctor
'     of the class can also be coded.
'     The parameter contains the language (English, Franais, Deutsch, Espaol,
'     Portugues, Italiano, etc)
'     The function must return True if everything is Ok, then the plug-in will be used.
'     If the function returns False, the plug-in will not be called anymore.
'
'   EPI_GetCardObject(object)
'     This method is called just after the call to EPI_Initialize, and provides
'     an eMedia.CardObjects object in the argument. This object can be used by
'     your plug-in to request information from eMedia. Please refer to the
'     CardObjects class members documentation for more information.
'
'   EPI_Terminate()
'     This method is called when eMedia needs the Plug-In to terminate function
'     (When eMedia is closed or when the user deactivate this plug-in). The
'     destructor of the class can also be coded.
'
'   EPI_Preferences(Form)
'     This method is called by eMedia when the user selects in the "Plug-In" menu
'     the name of the plug-in. You can configure it there, display a dialog, and
'     so on. The parameter contains the instance of the main application form.
'
'   EPI_Supports(enumPlugInOperations)
'     Called before EPI_Job to know the Plug-In capabilities. This method must return
'     True or False, depending on the operations that the plug-in manages. If the method
'     doesn't exist, then eMedia will consider that the Plug-In supports all operations.
'
'   EPI_SetMode(enumPlugInModes)
'     Called when the user goes to creation or exploitation mode. The parameter value
'     reflects the new mode of utilization.
'
'   EPI_Job(enumPlugInOperations)
'     Called first for each record added / modified / deleted, when the card is
'     printed, when an image acquisition is done and when CoolReader find a record.
'     Called again at the end of the operation for information. The parameter tells
'     you what is the operation.
'     The call to this method is followed by one call to EPI_Database, then by zero,
'     one or more calls to EPI_DataTransmit, then by one call to EPI_Job(PlugInEnd).
'
'   EPI_Database(ADODB.Recordset)
'     Called just after EPI_Job. The parameter IS the ADODB Recordset object used
'     by eMedia. So, use it very carefully to avoid problems. The current record
'     in this recordset is the one used by eMedia. If you plan to use this object,
'     clone it before with the .clone method, use the cloned recordset, then delete it.
'
'   EPI_DataTransmit(enumPlugInDataSource, String, Variant, Long)
'     Called for each field of the record/card. The first parameter always contains the
'     type of the value name. The second parameter contains the object/field name,
'     the third parameter contains the object/field value, the fourth parameter contains
'     the length of the data.
'
'---------------------------------------------------------------------------------------------------------------------------------------



'---------------------------------------------------------------------------------------------------------------------------------------
' public enumerations
'---------------------------------------------------------------------------------------------------------------------------------------

'Current job information, for EPI_Job
Public Enum enumPlugInOperations
  PlugInEnd = 0
  PlugInDBAdd = 1
  PlugInDBModify = 2
  PlugInDBDelete = 3
  PlugInPrint = 4
  PlugInAcquire = 5
  PlugInCoolReader = 6
  PlugInCardOpen = 7
  PlugInCardSave = 8
  PlugInCardNew = 9
End Enum

'Source of data, for EPI_DataTransmit
Public Enum enumPlugInDataSource
  PlugInDBField = &H1
  PlugInDBRecordNo = &H2
  PlugInCardObject = &H4
  PlugInFrontSide = &H8
  PlugInBackSide = &H10
  PlugInSmartCard = &H20
  PlugInMagneticStrip1 = &H40
  PlugInMagneticStrip2 = &H80
  PlugInMagneticStrip3 = &H100
  PlugInContactLess = &H200
  PlugInStartEncoding = &H400
  PlugInStartPrinting = &H800
  PlugInCardInfo = &H1000
End Enum

'For eMedia utilization mode, for EPI_SetMode
Public Enum enumPlugInModes
  PlugInDesign = 0
  PlugInOperation = 1
End Enum

'For eMedia database links
Public Enum enumDBEngine
  engNone = -1
  engAccess95 = 0
  engSQLServer = 1
  engOracle = 2
  engODBC = 3
  engAccess2000 = 4
  engExcel = 5
  engOLEDB = 6
End Enum



'---------------------------------------------------------------------------------------------------------------------------------------
' Internal data
'---------------------------------------------------------------------------------------------------------------------------------------

Private m_Operation As String
Private m_Active As Boolean

Private m_Recordset As ADODB.Recordset

Private m_eMediaObject As Object



'---------------------------------------------------------------------------------------------------------------------------------------
' Active Property: TRUE if the Plug-In is used
'---------------------------------------------------------------------------------------------------------------------------------------

Public Property Let Active(ByVal vActive As Boolean)
  m_Active = vActive
  If vActive Then
    MsgBox "The sample plug-in has been activated"
  Else
    MsgBox "The sample plug-in has been deactivated"
  End If
End Property

Public Property Get Active() As Boolean
  Active = m_Active
End Property



'---------------------------------------------------------------------------------------------------------------------------------------
' This function is called for initialization
'---------------------------------------------------------------------------------------------------------------------------------------

Public Function EPI_Initialize(ByVal CurrentLanguage As String) As Boolean
Attribute EPI_Initialize.VB_Description = "Method called at initialization time."
  'The plug-in will be active by default, as this sample doesn't offer any way to set it to true or false
  MsgBox "The sample plug-in is initializing, its language has been set to " + LCase(CurrentLanguage)
  Me.Active = True
  EPI_Initialize = True
End Function



'---------------------------------------------------------------------------------------------------------------------------------------
' This function is called to provide a callback object
'---------------------------------------------------------------------------------------------------------------------------------------

Public Sub EPI_GetCardObject(TheObject As Object)
  On Error Resume Next
  'Note that eMediaObject is an instance of the eMedia.CardObjects class
  'To allow early binding, please add a reference to the "eMedia Card Designer" application
  'in the Project.References menu command, change the "Object" type above to "eMedia.CardObjects"
  'and change the type of the m_eMediaObject variable to "eMedia.CardObjects"
  MsgBox "The EPI_GetCardObject method has been called."
  Set m_eMediaObject = TheObject
  'Now, it's possible to call some method of the eMedia.CardObjects class, such as:
  'MsgBox "The current card template in eMedia is:" & vbCrLf & m_eMediaObject.GetCardFilename()
  Err.Clear
End Sub



'---------------------------------------------------------------------------------------------------------------------------------------
' This function is called for termination
'---------------------------------------------------------------------------------------------------------------------------------------

Public Sub EPI_Terminate()
Attribute EPI_Terminate.VB_Description = "Method called at termination time."
  MsgBox "The sample plug-in is successfully terminating"
End Sub



'---------------------------------------------------------------------------------------------------------------------------------------
' This function is called for configuration
'---------------------------------------------------------------------------------------------------------------------------------------

Public Sub EPI_Preferences(AppForm As Object)
Attribute EPI_Preferences.VB_Description = "Method called for user preferences."
  MsgBox "The sample plug-in preferences dialog-box goes there"
End Sub



'---------------------------------------------------------------------------------------------------------------------------------------
' This function is called to check the plug-in capabilities
'---------------------------------------------------------------------------------------------------------------------------------------

Public Function EPI_Supports(ByVal lngFunctionality As enumPlugInOperations) As Boolean
  Select Case lngFunctionality
    Case PlugInPrint:       EPI_Supports = True
    Case PlugInEnd:         EPI_Supports = True
    Case PlugInDBModify:    EPI_Supports = True
    Case PlugInDBDelete:    EPI_Supports = True
    Case PlugInDBAdd:       EPI_Supports = True
    Case PlugInCoolReader:  EPI_Supports = True
    Case PlugInAcquire:     EPI_Supports = True
    Case PlugInCardOpen:    EPI_Supports = True
    Case PlugInCardSave:    EPI_Supports = True
    Case PlugInCardNew:     EPI_Supports = True
  End Select
End Function



'---------------------------------------------------------------------------------------------------------------------------------------
' This function is called when the user go to the exploitation or creation mode
'---------------------------------------------------------------------------------------------------------------------------------------

Public Sub EPI_SetMode(ByVal lngNewMode As enumPlugInModes)
  If lngNewMode = PlugInDesign Then
    MsgBox "The sample plug-in has been notified that user is in design mode"
  ElseIf lngNewMode = PlugInOperation Then
    MsgBox "The sample plug-in has been notified that user is in operation mode"
  Else
    MsgBox "The sample plug-in has been notified that user is in an unknown mode !"
  End If
End Sub



'---------------------------------------------------------------------------------------------------------------------------------------
' This function is called at the beginning and at the end of every operation
'---------------------------------------------------------------------------------------------------------------------------------------
' Note: The parameter contains the operation that eMedia is performing

Public Sub EPI_Job(ByVal op As enumPlugInOperations)
  'The operation is saved in the m_Operation module variable, because it may be used in the EPI_DataTransmit method.
  Select Case op
    Case PlugInPrint:         m_Operation = "Print"
    Case PlugInDBModify:      m_Operation = "Database record modification"
    Case PlugInDBDelete:      m_Operation = "Database record deletion"
    Case PlugInDBAdd:         m_Operation = "Database record insertion"
    Case PlugInEnd:           m_Operation = "End of operation"
    Case PlugInAcquire:       m_Operation = "Image acquisition"
    Case PlugInCoolReader:    m_Operation = "CoolReader did found a record"
    Case PlugInCardOpen:      m_Operation = "A card was opened"
    Case PlugInCardSave:      m_Operation = "The card was saved"
    Case PlugInCardNew:       m_Operation = "A new card has been created"
  End Select
  MsgBox "The sample plug-in received the operation: " & m_Operation
End Sub



'---------------------------------------------------------------------------------------------------------------------------------------
' This function is called to provide the current recordset
'---------------------------------------------------------------------------------------------------------------------------------------

Public Sub EPI_Database(ByVal rsData As ADODB.Recordset, ByVal lngDatabaseEngine As enumDBEngine)
  If rsData Is Nothing Then
    'There is no recordset
    MsgBox "The sample plug-in received the recordset object: no recordset."
  Else
    'rsData IS the eMedia recordset. Clone it and use the copy
    Set m_Recordset = rsData.Clone(adLockPessimistic)
    m_Recordset.Bookmark = rsData.Bookmark
    MsgBox "The sample plug-in received the recordset object." & vbCrLf & "The database engine used is: " & lngDatabaseEngine & "." & vbCrLf & "Current record: " & m_Recordset.AbsolutePosition
  End If
End Sub



'---------------------------------------------------------------------------------------------------------------------------------------
' This function is called to provide card objects and values, or database field names and values
'---------------------------------------------------------------------------------------------------------------------------------------

Public Sub EPI_DataTransmit(ByVal parmSource As enumPlugInDataSource, _
                            ByVal parmName As String, _
                            ByVal parmValue As Variant, _
                            ByVal parmSize As Long)
Dim strSource As String
  'Converting the parmSource into readable text, for the message box below
  strSource = ""
  If (parmSource And PlugInFrontSide) = PlugInFrontSide Then _
    strSource = strSource + ", front side of the card"
  If (parmSource And PlugInBackSide) = PlugInBackSide Then _
    strSource = strSource + ", back side of the card"
  If (parmSource And PlugInMagneticStrip1) = PlugInMagneticStrip1 Then _
    strSource = strSource + ", magnetic strip #1 data"
  If (parmSource And PlugInMagneticStrip2) = PlugInMagneticStrip2 Then _
    strSource = strSource + ", magnetic strip #2 data"
  If (parmSource And PlugInMagneticStrip3) = PlugInMagneticStrip3 Then _
    strSource = strSource + ", magnetic strip #3 data"
  If (parmSource And PlugInSmartCard) = PlugInSmartCard Then _
    strSource = strSource + ", smart card data"
  If (parmSource And PlugInContactLess) = PlugInContactLess Then _
    strSource = strSource + ", contactless smart card data"
  If (parmSource And PlugInDBRecordNo) = PlugInDBRecordNo Then _
    strSource = strSource + ", record number information"
  If (parmSource And PlugInDBField) = PlugInDBField Then _
    strSource = strSource + ", database field data"
  If (parmSource And PlugInCardObject) = PlugInCardObject Then _
    strSource = strSource + ", card object data"
  If (parmSource And PlugInStartEncoding) = PlugInStartEncoding Then _
    strSource = strSource + ", beginning to encode"
  If (parmSource And PlugInStartPrinting) = PlugInStartPrinting Then _
    strSource = strSource + ", beginning to print"
  If (parmSource And PlugInCardInfo) = PlugInCardInfo Then _
    strSource = strSource + ", card information"
  If Len(strSource) > 2 Then strSource = Mid(strSource, 3)
  'Display the message box
  MsgBox "The sample plug-in received for operation: " & m_Operation & vbCrLf & _
         "The datasource is: " & strSource & vbCrLf & _
         "The object/field named: " & parmName & vbCrLf & _
         "Its value is: " & parmValue & vbCrLf & _
         "Its length is: " & parmSize
'  'When the objects printout begins...
'  '  1) the text field "PRINT_DATE" of the current record is set to the current date/time
'  '  2) the numeric field "PRINT_COUNT" of the current record is incremented
'  'You can uncomment all this block to permit this to occur.
'  If parmSource = PlugInStartPrinting Then
'    On Error Resume Next
'    m_Recordset("PRINT_DATE").Value = Format(Now, "mm/dd/yyyy hh:mm:ss")
'    m_Recordset("PRINT_COUNT").Value = m_Recordset("PRINT_COUNT").Value + 1
'    m_Recordset.Update
'    Err.Clear
'  End If
End Sub



'EOF
